pub struct Scene<T: SceneTemplate> { /* private fields */ }Expand description
A scene containing test data created by the seeder
The scene wraps a template instance with the server response data.
Cleanup is handled by the owning Play instance when it is dropped.
Implementations